==> ark-19.08.3.tar.xz: ark-19.08.3/part/ark_part.desktop.cmake <==
[Desktop Entry]
Icon=ark
Name=Archiver
Name[af]=Argifeerder
Name[ar]=المؤرشف
Name[bg]=Архиватор
Name[br]=Dieller
Name[bs]=Arhivar
Name[ca]=Arxivador
Name[ca@valencia]=Arxivador
Name[cs]=Archivátor
Name[cy]=Archifydd
Name[da]=Arkivbehandler
Name[de]=Archivprogramm
Name[el]=Πρόγραμμα αρχειοθέτησης
Name[en_GB]=Archiver
Name[eo]=Arkivilo
Name[es]=Archivador
Name[et]=Arhiveerija
Name[eu]=Artxibatzeko programa
Name[fa]=بایگانی‌کننده
Name[fi]=Pakkausohjelma
Name[fr]=Archiveur
Name[ga]=Archiver
Name[gl]=Arquivador
Name[he]=מנהל הארכיונים
Name[hne]=अभिलेखक
Name[hr]=Arhiver
Name[hu]=Ark fájltömörítő
Name[ia]=Archivator
Name[id]=Pengarsip
Name[is]=Skráasafnari
Name[it]=Utilità di archiviazione
Name[ja]=アーカイバ
Name[kk]=Архивтегіш
Name[km]=កម្មវិធីប័ណ្ណសារ
Name[ko]=Archiver
Name[lt]=Archyvatorius
Name[lv]=Arhivātors
Name[mk]=Архивер
Name[mr]=संग्रहकर्ता
Name[ms]=Pengarkib
Name[nb]=Arkivbehandler
Name[nds]=Archivater
Name[ne]=सङ्ग्रहक
Name[nl]=Archiefgereedschap
Name[nn]=Arkivprogram
Name[pa]=ਅਕਾਇਵਰ
Name[pl]=Ark
Name[pt]=Ark
Name[pt_BR]=Arquivador
Name[ro]=Arhivator
Name[ru]=Архиватор
Name[sk]=Archivačný nástroj
Name[sl]=Pakirnik
Name[sq]=Arkivues
Name[sr]=Архивар
Name[sr@ijekavian]=Архивар
Name[sr@ijekavianlatin]=Arhivar
Name[sr@latin]=Arhivar
Name[sv]=Arkiverare
Name[ta]=காப்பகம் உருவாக்கி
Name[tg]=Бойгонигар
Name[th]=ตัวสร้างแฟ้มจัดเก็บ
Name[tr]=Arşivleyici
Name[uk]=Архіватор
Name[uz]=Arxivlagich
Name[uz@cyrillic]=Архивлагич
Name[vi]=Trình Lưu Trữ
Name[wa]=Årtchiveu
Name[xh]=Umenzi woshicilelo lukawonke-wonke noxwebhu lweMbali
Name[x-test]=xxArchiverxx
Name[zh_CN]=压缩存档工具
Name[zh_TW]=壓縮檔處理器
Comment=Archive Handling Tool
Comment[af]=Argief Handtering Program
Comment[ar]=أداة التعامل مع الملفات المضغوطة
Comment[bg]=Работа с архиви
Comment[br]=Ostilh merañ an dielloù
Comment[bs]=Alatka za rukovanje arhivama
Comment[ca]=Eina per a treballar amb arxius
Comment[ca@valencia]=Eina per a treballar amb arxius
Comment[cs]=Program pro práci s archivy
Comment[cy]=Erfyn Triniaeth Archif
Comment[da]=Arkivbehandlingsværktøj
Comment[de]=Archiv-Verwaltung
Comment[el]=Εργαλείο χειρισμού αρχειοθηκών
Comment[en_GB]=Archive Handling Tool
Comment[eo]=Administrilo por arĥivoj
Comment[es]=Herramienta de gestión de archivos
Comment[et]=Arhiivide haldamise rakendus
Comment[eu]=Artxiboak kudeatzeko tresna
Comment[fa]=ابزار گرداندن بایگانی
Comment[fi]=Pakkausohjelma
Comment[fr]=Outil de manipulation d'archives
Comment[ga]=Uirlis Láimhseála Cartlainne
Comment[gl]=Utilidade de manexo de arquivos
Comment[he]=כלי לניהול ארכיונים
Comment[hne]=अभिलेख संभाल औजार
Comment[hr]=Uslužni program za arhiviranje
Comment[hu]=Tömörítőprogram
Comment[ia]=Instrumento de manear archivo
Comment[id]=Alat Penanganan Arsip
Comment[is]=Vinna með safnskrár
Comment[it]=Gestione degli archivi
Comment[ja]=アーカイブを操作するツール
Comment[kk]=Архивпен айналысу құралы
Comment[km]=ឧបករណ៍​គ្រប់គ្រង​ប័ណ្ណសារ
Comment[ko]=압축 파일 도구
Comment[lt]=Archyvo valdymo priemonė
Comment[lv]=Arhīvu apstrādes rīks
Comment[mk]=Алатка за справување со архивирани датотеки
Comment[mr]=संग्रह हाताळणारे साधन
Comment[ms]=Alatan Pengendalian Arkib
Comment[nb]=Arkivbehandlingsverktøy
Comment[nds]=En Warktüüch för de Archievpleeg
Comment[ne]=ह्यान्डलिङ उपकरण सङ्ग्रह गर्नुहोस्
Comment[nl]=Hulpprogramma voor het beheren van archieven
Comment[nn]=Verktøy for arkivhandsaming
Comment[pa]=ਅਕਾਇਵ ਹੈਡਲਿੰਗ ਟੂਲ
Comment[pl]=Program obsługi archiwów
Comment[pt]=Programa de gestão de arquivos
Comment[pt_BR]=Ferramenta de manipulação de arquivos
Comment[ro]=Utilitar de manipulare arhive
Comment[ru]=Программа работы с архивами
Comment[sk]=Nástroj na prácu s archívmi
Comment[sl]=Orodje za ravnanje z arhivi
Comment[sq]=Mjet Për Përpunimin e Arkivave
Comment[sr]=Алатка за руковање архивама
Comment[sr@ijekavian]=Алатка за руковање архивама
Comment[sr@ijekavianlatin]=Alatka za rukovanje arhivama
Comment[sr@latin]=Alatka za rukovanje arhivama
Comment[sv]=Verktyg för att hantera filarkiv
Comment[ta]=காப்பகத்தை கையாளும் கருவி
Comment[tg]=Асбобҳои Дасткории Бойгонӣ
Comment[th]=เครื่องมือจัดการแฟ้มจัดเก็บ
Comment[tr]=Arşiv İşleme Aracı
Comment[uk]=Засіб роботи з архівами
Comment[uz]=Arxiv uchun vosita
Comment[uz@cyrillic]=Архив учун восита
Comment[vi]=Công Cụ Xử Lý Các Tập Tin Nén
Comment[wa]=Usteye po-z apougnî les årtchives
Comment[xh]=Isixhobo sokuphatha i Archive
Comment[x-test]=xxArchive Handling Toolxx
Comment[zh_CN]=压缩归档处理工具
Comment[zh_TW]=壓縮檔處理工具
X-KDE-ServiceTypes=KParts/ReadOnlyPart,Browser/View
X-KDE-Library=arkpart
Type=Service
MimeType=@SUPPORTED_ARK_MIMETYPES@

==> ark_19.12.3.orig.tar.xz: ark-19.12.3/part/ark_part.desktop.cmake <==
[Desktop Entry]
Icon=ark
Name=Archiver
Name[af]=Argifeerder
Name[ar]=المؤرشف
Name[bg]=Архиватор
Name[br]=Dieller
Name[bs]=Arhivar
Name[ca]=Arxivador
Name[ca@valencia]=Arxivador
Name[cs]=Archivátor
Name[cy]=Archifydd
Name[da]=Arkivbehandler
Name[de]=Archivprogramm
Name[el]=Πρόγραμμα αρχειοθέτησης
Name[en_GB]=Archiver
Name[eo]=Arkivilo
Name[es]=Archivador
Name[et]=Arhiveerija
Name[eu]=Artxibatzeko programa
Name[fa]=بایگانی‌کننده
Name[fi]=Pakkausohjelma
Name[fr]=Archiveur
Name[ga]=Archiver
Name[gl]=Arquivador
Name[he]=מנהל הארכיונים
Name[hne]=अभिलेखक
Name[hr]=Arhiver
Name[hu]=Ark fájltömörítő
Name[ia]=Archivator
Name[id]=Pengarsip
Name[is]=Skráasafnari
Name[it]=Utilità di archiviazione
Name[ja]=アーカイバ
Name[kk]=Архивтегіш
Name[km]=កម្មវិធីប័ណ្ណសារ
Name[ko]=Archiver
Name[lt]=Archyvavimo programa
Name[lv]=Arhivātors
Name[mk]=Архивер
Name[mr]=संग्रहकर्ता
Name[ms]=Pengarkib
Name[nb]=Arkivbehandler
Name[nds]=Archivater
Name[ne]=सङ्ग्रहक
Name[nl]=Archiefgereedschap
Name[nn]=Arkivprogram
Name[pa]=ਅਕਾਇਵਰ
Name[pl]=Ark
Name[pt]=Ark
Name[pt_BR]=Arquivador
Name[ro]=Arhivator
Name[ru]=Архиватор
Name[sk]=Archivačný nástroj
Name[sl]=Pakirnik
Name[sq]=Arkivues
Name[sr]=Архивар
Name[sr@ijekavian]=Архивар
Name[sr@ijekavianlatin]=Arhivar
Name[sr@latin]=Arhivar
Name[sv]=Arkiverare
Name[ta]=காப்பகம் உருவாக்கி
Name[tg]=Бойгонигар
Name[th]=ตัวสร้างแฟ้มจัดเก็บ
Name[tr]=Arşivleyici
Name[uk]=Архіватор
Name[uz]=Arxivlagich
Name[uz@cyrillic]=Архивлагич
Name[vi]=Trình Lưu Trữ
Name[wa]=Årtchiveu
Name[xh]=Umenzi woshicilelo lukawonke-wonke noxwebhu lweMbali
Name[x-test]=xxArchiverxx
Name[zh_CN]=压缩存档工具
Name[zh_TW]=壓縮檔處理器
Comment=Archive Handling Tool
Comment[af]=Argief Handtering Program
Comment[ar]=أداة التعامل مع الملفات المضغوطة
Comment[bg]=Работа с архиви
Comment[br]=Ostilh merañ an dielloù
Comment[bs]=Alatka za rukovanje arhivama
Comment[ca]=Eina per a treballar amb arxius
Comment[ca@valencia]=Eina per a treballar amb arxius
Comment[cs]=Program pro práci s archivy
Comment[cy]=Erfyn Triniaeth Archif
Comment[da]=Arkivbehandlingsværktøj
Comment[de]=Archiv-Verwaltung
Comment[el]=Εργαλείο χειρισμού αρχειοθηκών
Comment[en_GB]=Archive Handling Tool
Comment[eo]=Administrilo por arĥivoj
Comment[es]=Herramienta de gestión de archivos
Comment[et]=Arhiivide haldamise rakendus
Comment[eu]=Artxiboak kudeatzeko tresna
Comment[fa]=ابزار گرداندن بایگانی
Comment[fi]=Pakkausohjelma
Comment[fr]=Outil de manipulation d'archives
Comment[ga]=Uirlis Láimhseála Cartlainne
Comment[gl]=Utilidade de manexo de arquivos
Comment[he]=כלי לניהול ארכיונים
Comment[hne]=अभिलेख संभाल औजार
Comment[hr]=Uslužni program za arhiviranje
Comment[hu]=Tömörítőprogram
Comment[ia]=Instrumento de manear archivo
Comment[id]=Alat Penanganan Arsip
Comment[is]=Vinna með safnskrár
Comment[it]=Gestione degli archivi
Comment[ja]=アーカイブを操作するツール
Comment[kk]=Архивпен айналысу құралы
Comment[km]=ឧបករណ៍​គ្រប់គ្រង​ប័ណ្ណសារ
Comment[ko]=압축 파일 도구
Comment[lt]=Archyvų apdorojimo įrankis
Comment[lv]=Arhīvu apstrādes rīks
Comment[mk]=Алатка за справување со архивирани датотеки
Comment[mr]=संग्रह हाताळणारे साधन
Comment[ms]=Alatan Pengendalian Arkib
Comment[nb]=Arkivbehandlingsverktøy
Comment[nds]=En Warktüüch för de Archievpleeg
Comment[ne]=ह्यान्डलिङ उपकरण सङ्ग्रह गर्नुहोस्
Comment[nl]=Hulpprogramma voor het beheren van archieven
Comment[nn]=Verktøy for arkivhandsaming
Comment[pa]=ਅਕਾਇਵ ਹੈਡਲਿੰਗ ਟੂਲ
Comment[pl]=Program obsługi archiwów
Comment[pt]=Programa de gestão de arquivos
Comment[pt_BR]=Ferramenta de manipulação de arquivos
Comment[ro]=Utilitar de manipulare arhive
Comment[ru]=Программа работы с архивами
Comment[sk]=Nástroj na prácu s archívmi
Comment[sl]=Orodje za ravnanje z arhivi
Comment[sq]=Mjet Për Përpunimin e Arkivave
Comment[sr]=Алатка за руковање архивама
Comment[sr@ijekavian]=Алатка за руковање архивама
Comment[sr@ijekavianlatin]=Alatka za rukovanje arhivama
Comment[sr@latin]=Alatka za rukovanje arhivama
Comment[sv]=Verktyg för att hantera filarkiv
Comment[ta]=காப்பகத்தை கையாளும் கருவி
Comment[tg]=Асбобҳои Дасткории Бойгонӣ
Comment[th]=เครื่องมือจัดการแฟ้มจัดเก็บ
Comment[tr]=Arşiv İşleme Aracı
Comment[uk]=Засіб роботи з архівами
Comment[uz]=Arxiv uchun vosita
Comment[uz@cyrillic]=Архив учун восита
Comment[vi]=Công Cụ Xử Lý Các Tập Tin Nén
Comment[wa]=Usteye po-z apougnî les årtchives
Comment[xh]=Isixhobo sokuphatha i Archive
Comment[x-test]=xxArchive Handling Toolxx
Comment[zh_CN]=压缩归档处理工具
Comment[zh_TW]=壓縮檔處理工具
X-KDE-ServiceTypes=KParts/ReadOnlyPart,Browser/View
X-KDE-Library=arkpart
Type=Service
MimeType=@SUPPORTED_ARK_MIMETYPES@
